```
Usage: vcd network routed add-dns [OPTIONS] <routed network name>

Options:
  --dns1 <ip>          ip of the primary dns server
  --dns2 <ip>          ip of the secondary dns server
  --dns-suffix <name>  dns suffix
  -h, --help           Show this message and exit.

```
